@@ -1,4 +1,3 @@
-import yaml
 import subprocess
 import os
 from workspace import env, message, env
@@ -50,6 +49,12 @@ def install(repository_name, source):
 
     message.run_or_fail(cmd)
 
+    config = env.get_config(repository['directory'])
+    if config and 'install' in config:
+        for command in config['install']:
+            cmd = 'cd %s; %s' % (repository['directory'], command)
+            message.run_or_fail(cmd)
+
     return True
   else:
     if repository['branch']:
